theme_dictionary <- list(
  "default" = theme_default,
  "grid" = theme_grid,
  "revealjs" = theme_revealjs,
  "rotate" = theme_rotate,
  "striped" = theme_striped,
  "empty" = theme_empty
)
